@@ -431,8 +431,6 @@ g_local_file_get_parse_name (GFile *file)
 	      g_free (utf8_filename);
 	      utf8_filename = NULL;
 	    }
-
-	  g_free (roundtripped_filename);
 	}
     }
 
@@ -592,7 +590,7 @@ g_local_file_get_child_for_display_name (GFile        *file,
 					 const char   *display_name,
 					 GError      **error)
 {
-  GFile *new_file;
+  GFile *parent, *new_file;
   char *basename;
 
   basename = g_filename_from_utf8 (display_name, -1, NULL, NULL, NULL);
@@ -604,7 +602,9 @@ g_local_file_get_child_for_display_name (GFile        *file,
       return NULL;
     }
 
+  parent = g_file_get_parent (file);
   new_file = g_file_get_child (file, basename);
+  g_object_unref (parent);
   g_free (basename);
   
   return new_file;
@@ -779,7 +779,7 @@ get_mount_info (GFileInfo             *fs_info,
 
       mountpoint = find_mountpoint_for (path, buf.st_dev);
       if (mountpoint == NULL)
-	mountpoint = g_strdup ("/");
+	mountpoint = "/";
 
       mount = g_unix_mount_at (mountpoint, &cache_time);
       if (mount)
@@ -790,8 +790,6 @@ get_mount_info (GFileInfo             *fs_info,
 	  g_unix_mount_free (mount);
 	}
 
-      g_free (mountpoint);
-
       dev = g_new0 (dev_t, 1);
       *dev = buf.st_dev;
       
